aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/contrib/lite/util.h
diff options
context:
space:
mode:
authorGravatar Nupur Garg <nupurgarg@google.com>2018-09-26 18:26:51 -0700
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2018-09-26 18:31:32 -0700
commit51a6118e5bd85935b1d9ec0e68b92f1f98d14982 (patch)
tree5b3d7b469bebd510b678a2054c04311e4879fd09 /tensorflow/contrib/lite/util.h
parent78ee51bb8c41d616c01674e405784a51e4ec98a5 (diff)
Automated rollback of commit 82af048bc8c3c044c98a27b1c4c27bb62d4e4a14
PiperOrigin-RevId: 214705311
Diffstat (limited to 'tensorflow/contrib/lite/util.h')
-rw-r--r--tensorflow/contrib/lite/util.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tensorflow/contrib/lite/util.h b/tensorflow/contrib/lite/util.h
index 31292a6f81..6d81f844f8 100644
--- a/tensorflow/contrib/lite/util.h
+++ b/tensorflow/contrib/lite/util.h
@@ -26,15 +26,15 @@ limitations under the License.
namespace tflite {
// The prefix of Flex op custom code.
// This will be matched agains the `custom_code` field in `OperatorCode`
// Flatbuffer Table.
// WARNING: This is an experimental API and subject to change.
-constexpr char kFlexCustomCodePrefix[] = "Flex";
+constexpr char kEagerCustomCodePrefix[] = "Eager";
// Checks whether the prefix of the custom name indicates the operation is an
-// Flex operation.
-bool IsFlexOp(const char* custom_name);
+// Eager operation.
+bool IsEagerOp(const char* custom_name);
// Converts a `std::vector` to a `TfLiteIntArray`. The caller takes ownership
// of the returned pointer.
@@ -26,15 +26,15 @@ limitations under the License.
namespace tflite {
-// The prefix of Flex op custom code.
+// The prefix of Eager op custom code.
// This will be matched agains the `custom_code` field in `OperatorCode`
// Flatbuffer Table.